@@ -7,7 +7,7 @@ from .. import Cert, HTTPRequester, WebhookReceiver, WebsocketReceiver, Gateway,
 from .. import User, Channel, PublicChannel, PublicTextChannel, Guild, Event, Message  # concepts
 from ..command import CommandManager
 from ..game import Game
-from ..interface import SlowModeTypes
+from ..interface import SlowModeTypes, SoftwareTypes
 from ..task import TaskManager
 
 log = logging.getLogger(__name__)
@@ -110,7 +110,7 @@ class Bot(AsyncRunnable):
         """
 
         async def handler(msg: Message):
-            await self.command.handle(self.loop, msg, {Message: msg, Bot: self})
+            await self.command.handle(self.loop, self.client, msg, {Message: msg, Bot: self})
 
         return handler
 
@@ -158,7 +158,7 @@ class Bot(AsyncRunnable):
         """
 
         def dec(func: MessageHandler):
-            self.add_message_handler(func, *set(except_type + (MessageTypes.SYS,)))
+            self.add_message_handler(func, *set(except_type + (MessageTypes.SYS, )))
 
         return dec
 
@@ -303,7 +303,7 @@ class Bot(AsyncRunnable):
         """
         await self.client.delete_game(game)
 
-    async def update_playing_game(self, game: Union[Game, int], data_type: int = 1):
+    async def update_playing_game(self, game: Union[Game, int]):
         """
 
         update current playing game status
@@ -312,7 +312,7 @@ class Bot(AsyncRunnable):
         :param data_type: 1 in default(means playing type is game)
 
         """
-        await self.client.update_playing_game(game, data_type)
+        await self.client.update_playing_game(game)
 
     async def stop_playing_game(self):
         """
@@ -322,7 +322,32 @@ class Bot(AsyncRunnable):
         """
         await self.client.stop_playing_game()
 
-    async def update_channel(self, channel: Union[str, PublicChannel], name: str = None, topic: str = None, slow_mode: Union[int, SlowModeTypes] = None):
+    async def update_listening_music(self, music_name: str, singer: str, software: Union[str, SoftwareTypes]):
+        """
+
+        update current listening music status
+
+        :param music_name: name of music
+        :param singer: singer of the music
+        :param software: set software to playing the music
+        :param data_type: 2 in default(means playing type is music)
+
+        """
+        await self.client.update_listening_music(music_name, singer, software)
+
+    async def stop_listening_music(self):
+        """
+
+        clear current listening music status
+
+        """
+        await self.client.stop_listening_music()
+
+    async def update_channel(self,
+                             channel: Union[str, PublicChannel],
+                             name: str = None,
+                             topic: str = None,
+                             slow_mode: Union[int, SlowModeTypes] = None):
         """
         update channel's settings
         """
