@@ -2,7 +2,9 @@ import asyncio
 import copy
 import inspect
 import logging
-from typing import Dict, Any, Callable, List
+from typing import Dict, Any, Callable, List, Coroutine
+
+from .. import User, Channel, Client
 
 log = logging.getLogger(__name__)
 
@@ -21,24 +23,39 @@ def _get_param_type(params: List[inspect.Parameter], index: int):
     return result
 
 
+async def _parse_user(client, token) -> User:
+    if not (token.startswith("(met)") and token.startswith("(met)")):
+        raise Parser.ParseException(RuntimeError("Failed to parse user"))
+    return await client.fetch_user(token[5:len(token) - 5])
+
+
+async def _parse_channel(client, token) -> Channel:
+    if not (token.startswith("(chn)") and token.startswith("(chn)")):
+        raise Parser.ParseException(RuntimeError("Failed to parse channel"))
+    return await client.fetch_public_channel(token[5:len(token) - 5])
+
+
 class Parser:
     """
     deal with a list of tokens made from Lexer, convert their type to match the command.handler
     """
     _parse_funcs: Dict[Any, Callable] = {
-        str: lambda token: token,
-        int: lambda token: int(token),
-        float: lambda token: float(token)
-        # TODO: tag -> User/Channel/Role...
+        str: lambda client, token: token,
+        int: lambda client, token: int(token),
+        float: lambda client, token: float(token),
+        User: _parse_user,
+        Channel: _parse_channel
+        # TODO: Role parser
     }
 
     def __init__(self):
         self._parse_funcs = copy.copy(Parser._parse_funcs)
 
-    def parse(self, tokens: List[str], params: List[inspect.Parameter]) -> List[Any]:
+    async def parse(self, client: Client, tokens: List[str], params: List[inspect.Parameter]) -> List[Any]:
         """
         parse tokens into args that types corresponding to handler's requirement
 
+        :param client: bot client
         :param tokens: output of Lexer.lex()
         :param params: command handlers parameters
         :return: List of args
@@ -52,7 +69,10 @@ class Parser:
                 raise Parser.ParseFuncNotExists(params[i])
 
             try:
-                ret.append(self._parse_funcs[param_type](tokens[i]))
+                call = self._parse_funcs[param_type](client, tokens[i])
+                if isinstance(call, Coroutine):
+                    call = await call
+                ret.append(call)
             except Exception as e:
                 raise Parser.ParseException(e) from e
         return ret
